@@ -41,6 +41,19 @@ public:
     QString prettyStatusMessage() const override;
     JobResult exec() override;
 
+    /** @brief Sets the pre-run Python code for all PythonJobs
+     *
+     * A PythonJob runs the code from the scriptFile parameter to
+     * the constructor; the pre-run code is **also** run, before
+     * even the scriptFile code. Use this in testing mode
+     * to modify Python internals.
+     *
+     * No ownership of @p script is taken: pass in a pointer to
+     * a character literal or something that lives longer than the
+     * job. Pass in @c nullptr to switch off pre-run code.
+     */
+    static void setInjectedPreScript( const char* script );
+
 private:
     struct Private;
 
