@@ -33,7 +33,7 @@ static unsigned int s_threshold =
 #ifdef QT_NO_DEBUG
     Logger::LOG_DISABLE;
 #else
-    Logger::LOGEXTRA + 1;  // Comparison is < in log() function
+    Logger::LOGDEBUG;  // Comparison is < in log() function
 #endif
 static QMutex s_mutex;
 
@@ -69,7 +69,7 @@ logLevel()
 static void
 log( const char* msg, unsigned int debugLevel, bool withTime = true )
 {
-    if ( true )
+    if ( logLevelEnabled( debugLevel ) )
     {
         QMutexLocker lock( &s_mutex );
 
@@ -81,11 +81,7 @@ log( const char* msg, unsigned int debugLevel, bool withTime = true )
                 << QString::number( debugLevel ).toUtf8().data() << "]: " << msg << std::endl;
 
         logfile.flush();
-    }
 
-    if ( logLevelEnabled( debugLevel ) )
-    {
-        QMutexLocker lock( &s_mutex );
         if ( withTime )
         {
             std::cout << QTime::currentTime().toString().toUtf8().data() << " ["
@@ -105,20 +101,21 @@ CalamaresLogHandler( QtMsgType type, const QMessageLogContext&, const QString& m
     const char* message = ba.constData();
 
     QMutexLocker locker( &s_mutex );
+
     switch ( type )
     {
-    case QtDebugMsg:
+    case QtInfoMsg:
         log( message, LOGVERBOSE );
         break;
-
-    case QtInfoMsg:
-        log( message, 1 );
+    case QtDebugMsg:
+        log( message, LOGDEBUG );
         break;
-
-    case QtCriticalMsg:
     case QtWarningMsg:
+        log( message, LOGWARNING );
+        break;
+    case QtCriticalMsg:
     case QtFatalMsg:
-        log( message, 0 );
+        log( message, LOGERROR );
         break;
     }
 }
