@@ -18,6 +18,7 @@
 #include "utils/ImageRegistry.h"
 #include "utils/Logger.h"
 #include "utils/NamedEnum.h"
+#include "utils/Units.h"
 #include "utils/Yaml.h"
 
 #include <QDir>
@@ -153,15 +154,18 @@ uploadServerFromMap( const QVariantMap& map )
 
     QString typestring = map[ "type" ].toString();
     QString urlstring = map[ "url" ].toString();
+    qint64 sizeLimitKiB = map[ "sizeLimit" ].toLongLong();
 
     if ( typestring.isEmpty() || urlstring.isEmpty() )
     {
-        return Branding::UploadServerInfo( Branding::UploadServerType::None, QUrl() );
+        return Branding::UploadServerInfo( Branding::UploadServerType::None, QUrl(), 0 );
     }
 
     bool bogus = false;  // we don't care about type-name lookup success here
-    return Branding::UploadServerInfo( names.find( typestring, bogus ),
-                                       QUrl( urlstring, QUrl::ParsingMode::StrictMode ) );
+    return Branding::UploadServerInfo(
+        names.find( typestring, bogus ),
+        QUrl( urlstring, QUrl::ParsingMode::StrictMode ),
+        sizeLimitKiB >= 0 ? CalamaresUtils::KiBtoBytes( static_cast< unsigned long long >( sizeLimitKiB ) ) : -1 );
 }
 
 /** @brief Load the @p map with strings from @p config
