@@ -24,7 +24,6 @@
 #include "utils/CalamaresUtilsGui.h"
 #include "utils/Dirs.h"
 #include "utils/Logger.h"
-#include "utils/Qml.h"
 #include "utils/Retranslator.h"
 
 #include <QDir>
@@ -62,6 +61,10 @@ ExecutionViewStep::ExecutionViewStep( QObject* parent )
     , m_label( new QLabel )
     , m_slideshow( makeSlideshow( m_widget ) )
 {
+    m_widget->setObjectName( "slideshow" );
+    m_progressBar->setObjectName( "exec-progress" );
+    m_label->setObjectName( "exec-message" );
+
     QVBoxLayout* layout = new QVBoxLayout( m_widget );
     QVBoxLayout* innerLayout = new QVBoxLayout;
 
