@@ -1,19 +1,10 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2017-2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Tests.h"
@@ -36,20 +27,17 @@ using SizeUnit = CalamaresUtils::Partition::SizeUnit;
 
 QTEST_GUILESS_MAIN( FSResizerTests )
 
-FSResizerTests::FSResizerTests()
-{
-}
+FSResizerTests::FSResizerTests() {}
 
-FSResizerTests::~FSResizerTests()
-{
-}
+FSResizerTests::~FSResizerTests() {}
 
 void
 FSResizerTests::initTestCase()
 {
 }
 
-void FSResizerTests::testConfigurationRobust()
+void
+FSResizerTests::testConfigurationRobust()
 {
     ResizeFSJob j;
 
@@ -72,7 +60,8 @@ atleast: 600MiB
     QCOMPARE( j.minimumSize().value(), 0 );
 }
 
-void FSResizerTests::testConfigurationValues()
+void
+FSResizerTests::testConfigurationValues()
 {
     ResizeFSJob j;
 
@@ -84,7 +73,7 @@ atleast: 600MiB
 )" );
     j.setConfigurationMap( CalamaresUtils::yamlMapToVariant( doc0 ) );
     QVERIFY( !j.name().isEmpty() );
-    QCOMPARE( j.name(), QString("/") );
+    QCOMPARE( j.name(), QString( "/" ) );
     QCOMPARE( j.size().unit(), SizeUnit::Percent );
     QCOMPARE( j.minimumSize().unit(), SizeUnit::MiB );
     QCOMPARE( j.size().value(), 100 );
@@ -99,7 +88,7 @@ atleast: 127 %
 )" );
     j.setConfigurationMap( CalamaresUtils::yamlMapToVariant( doc0 ) );
     QVERIFY( !j.name().isEmpty() );
-    QCOMPARE( j.name(), QString("/") );
+    QCOMPARE( j.name(), QString( "/" ) );
     QCOMPARE( j.size().unit(), SizeUnit::MiB );
     QCOMPARE( j.minimumSize().unit(), SizeUnit::None );
     QCOMPARE( j.size().value(), 72 );
@@ -113,7 +102,7 @@ atleast: 127 %
 )" );
     j.setConfigurationMap( CalamaresUtils::yamlMapToVariant( doc0 ) );
     QVERIFY( !j.name().isEmpty() );
-    QCOMPARE( j.name(), QString("/dev/m00") );
+    QCOMPARE( j.name(), QString( "/dev/m00" ) );
     QCOMPARE( j.size().unit(), SizeUnit::MiB );
     QCOMPARE( j.minimumSize().unit(), SizeUnit::None );
     QCOMPARE( j.size().value(), 72 );
@@ -128,7 +117,7 @@ size: 71MiB
 )" );
     j.setConfigurationMap( CalamaresUtils::yamlMapToVariant( doc0 ) );
     QVERIFY( !j.name().isEmpty() );
-    QCOMPARE( j.name(), QString("/") );
+    QCOMPARE( j.name(), QString( "/" ) );
     QCOMPARE( j.size().unit(), SizeUnit::MiB );
     QCOMPARE( j.minimumSize().unit(), SizeUnit::None );
     QCOMPARE( j.size().value(), 71 );
