@@ -11,6 +11,7 @@
 #ifndef SETKEYBOARDLAYOUTJOB_H
 #define SETKEYBOARDLAYOUTJOB_H
 
+#include "AdditionalLayoutInfo.h"
 #include "Job.h"
 
 
@@ -21,6 +22,7 @@ public:
     SetKeyboardLayoutJob( const QString& model,
                           const QString& layout,
                           const QString& variant,
+                          const AdditionalLayoutInfo& additionaLayoutInfo,
                           const QString& xOrgConfFileName,
                           const QString& convertedKeymapPath,
                           bool writeEtcDefaultKeyboard );
@@ -38,6 +40,7 @@ private:
     QString m_model;
     QString m_layout;
     QString m_variant;
+    AdditionalLayoutInfo m_additionalLayoutInfo;
     QString m_xOrgConfFileName;
     QString m_convertedKeymapPath;
     const bool m_writeEtcDefaultKeyboard;
