@@ -1,20 +1,11 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2014 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2017 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "LCLocaleDialog.h"
@@ -25,9 +16,7 @@
 #include <QListWidget>
 #include <QPushButton>
 
-LCLocaleDialog::LCLocaleDialog( const QString& guessedLCLocale,
-                                const QStringList& localeGenLines,
-                                QWidget* parent )
+LCLocaleDialog::LCLocaleDialog( const QString& guessedLCLocale, const QStringList& localeGenLines, QWidget* parent )
     : QDialog( parent )
 {
     setModal( true );
@@ -41,7 +30,7 @@ LCLocaleDialog::LCLocaleDialog( const QString& guessedLCLocale,
     upperText->setText( tr( "The system locale setting affects the language and character "
                             "set for some command line user interface elements.<br/>"
                             "The current setting is <strong>%1</strong>." )
-                        .arg( guessedLCLocale ) );
+                            .arg( guessedLCLocale ) );
     mainLayout->addWidget( upperText );
     setMinimumWidth( upperText->fontMetrics().height() * 24 );
 
@@ -60,33 +49,32 @@ LCLocaleDialog::LCLocaleDialog( const QString& guessedLCLocale,
         }
     }
 
-    QDialogButtonBox* dbb = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel,
-            Qt::Horizontal,
-            this );
+    QDialogButtonBox* dbb
+        = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal, this );
     dbb->button( QDialogButtonBox::Cancel )->setText( tr( "&Cancel" ) );
     dbb->button( QDialogButtonBox::Ok )->setText( tr( "&OK" ) );
 
     mainLayout->addWidget( dbb );
 
-    connect( dbb->button( QDialogButtonBox::Ok ), &QPushButton::clicked,
-             this, &QDialog::accept );
-    connect( dbb->button( QDialogButtonBox::Cancel ), &QPushButton::clicked,
-             this, &QDialog::reject );
+    connect( dbb->button( QDialogButtonBox::Ok ), &QPushButton::clicked, this, &QDialog::accept );
+    connect( dbb->button( QDialogButtonBox::Cancel ), &QPushButton::clicked, this, &QDialog::reject );
 
-    connect( m_localesWidget, &QListWidget::itemDoubleClicked,
-             this, &QDialog::accept );
-    connect( m_localesWidget, &QListWidget::itemSelectionChanged,
-             [this, dbb]()
-    {
+    connect( m_localesWidget, &QListWidget::itemDoubleClicked, this, &QDialog::accept );
+    connect( m_localesWidget, &QListWidget::itemSelectionChanged, [this, dbb]() {
         if ( m_localesWidget->selectedItems().isEmpty() )
+        {
             dbb->button( QDialogButtonBox::Ok )->setEnabled( false );
+        }
         else
+        {
             dbb->button( QDialogButtonBox::Ok )->setEnabled( true );
-
+        }
     } );
 
     if ( selected > -1 )
+    {
         m_localesWidget->setCurrentRow( selected );
+    }
 }
 
 
