@@ -1,20 +1,11 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2016, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017-2019, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2016 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2017-2019 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "LocaleConfiguration.h"
@@ -37,7 +28,7 @@ LocaleConfiguration::LocaleConfiguration( const QString& localeName, const QStri
     lc_numeric = lc_time = lc_monetary = lc_paper = lc_name = lc_address = lc_telephone = lc_measurement
         = lc_identification = formatsName;
 
-    (void)setLanguage( localeName );
+    setLanguage( localeName );
 }
 
 
@@ -83,7 +74,7 @@ LocaleConfiguration::fromLanguageAndLocation( const QString& languageLocale,
     if ( language == "pt" || language == "zh" )
     {
         QString proposedLocale = QString( "%1_%2" ).arg( language ).arg( countryCode );
-        foreach ( QString line, linesForLanguage )
+        for ( const QString& line : linesForLanguage )
         {
             if ( line.contains( proposedLocale ) )
             {
