@@ -37,23 +37,8 @@ public:
     NetInstallPage( Config* config, QWidget* parent = nullptr );
     ~NetInstallPage() override;
 
-    /** @brief Sets the page title
-     *
-     * In situations where there is more than one netinstall page,
-     * or you want some explanatory title above the treeview,
-     * set the page title. This page takes ownership of the
-     * TranslatedString object.
-     *
-     * Set to nullptr to remove the title.
-     */
-    void setPageTitle( CalamaresUtils::Locale::TranslatedString* );
-
     void onActivate();
 
-public slots:
-    void retranslate();
-    void setStatus( QString s );
-
     /** @brief Expand entries that should be pre-expanded.
      *
      * Follows the *expanded* key / the startExpanded field in the
@@ -64,8 +49,6 @@ public slots:
 private:
     Config* m_config;
     Ui::Page_NetInst* ui;
-
-    std::unique_ptr< CalamaresUtils::Locale::TranslatedString > m_title;  // Above the treeview
 };
 
 #endif  // NETINSTALLPAGE_H
