@@ -22,6 +22,7 @@
 #include "partition/PartitionQuery.h"
 #include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
+#include "utils/RAII.h"
 
 #include <kpmcore/backend/corebackend.h>
 #include <kpmcore/backend/corebackendmanager.h>
@@ -72,15 +73,15 @@ getRequiredStorageGiB( bool& ok )
 }
 
 bool
-canBeReplaced( Partition* candidate )
+canBeReplaced( Partition* candidate, const Logger::Once& o )
 {
     if ( !candidate )
     {
-        cDebug() << "Partition* is NULL";
+        cDebug() << o << "Partition* is NULL";
         return false;
     }
 
-    cDebug() << "Checking if" << convenienceName( candidate ) << "can be replaced.";
+    cDebug() << o << "Checking if" << convenienceName( candidate ) << "can be replaced.";
     if ( candidate->isMounted() )
     {
         cDebug() << Logger::SubEntry << "NO, it is mounted.";
@@ -100,7 +101,7 @@ canBeReplaced( Partition* candidate )
 
     if ( availableStorageB > requiredStorageB )
     {
-        cDebug() << "Partition" << convenienceName( candidate ) << "authorized for replace install.";
+        cDebug() << o << "Partition" << convenienceName( candidate ) << "authorized for replace install.";
         return true;
     }
     else
@@ -117,15 +118,15 @@ canBeReplaced( Partition* candidate )
 
 
 bool
-canBeResized( Partition* candidate )
+canBeResized( Partition* candidate, const Logger::Once& o )
 {
     if ( !candidate )
     {
-        cDebug() << "Partition* is NULL";
+        cDebug() << o << "Partition* is NULL";
         return false;
     }
 
-    cDebug() << "Checking if" << convenienceName( candidate ) << "can be resized.";
+    cDebug() << o << "Checking if" << convenienceName( candidate ) << "can be resized.";
     if ( !candidate->fileSystem().supportGrow() || !candidate->fileSystem().supportShrink() )
     {
         cDebug() << Logger::SubEntry << "NO, filesystem" << candidate->fileSystem().name()
@@ -177,7 +178,8 @@ canBeResized( Partition* candidate )
 
     if ( availableStorageB > advisedStorageB )
     {
-        cDebug() << "Partition" << convenienceName( candidate ) << "authorized for resize + autopartition install.";
+        cDebug() << o << "Partition" << convenienceName( candidate )
+                 << "authorized for resize + autopartition install.";
         return true;
     }
     else
@@ -196,9 +198,9 @@ canBeResized( Partition* candidate )
 
 
 bool
-canBeResized( DeviceModel* dm, const QString& partitionPath )
+canBeResized( DeviceModel* dm, const QString& partitionPath, const Logger::Once& o )
 {
-    cDebug() << "Checking if" << partitionPath << "can be resized.";
+    cDebug() << o << "Checking if" << partitionPath << "can be resized.";
     QString partitionWithOs = partitionPath;
     if ( partitionWithOs.startsWith( "/dev/" ) )
     {
@@ -208,7 +210,7 @@ canBeResized( DeviceModel* dm, const QString& partitionPath )
             Partition* candidate = CalamaresUtils::Partition::findPartitionByPath( { dev }, partitionWithOs );
             if ( candidate )
             {
-                return canBeResized( candidate );
+                return canBeResized( candidate, o );
             }
         }
         cDebug() << Logger::SubEntry << "no Partition* found for" << partitionWithOs;
@@ -357,6 +359,8 @@ findPartitionPathForMountPoint( const FstabEntryList& fstab, const QString& moun
 OsproberEntryList
 runOsprober( DeviceModel* dm )
 {
+    Logger::Once o;
+
     QString osproberOutput;
     QProcess osprober;
     osprober.setProgram( "os-prober" );
@@ -410,19 +414,25 @@ runOsprober( DeviceModel* dm )
             FstabEntryList fstabEntries = lookForFstabEntries( path );
             QString homePath = findPartitionPathForMountPoint( fstabEntries, "/home" );
 
-            osproberEntries.append(
-                { prettyName, path, file, QString(), canBeResized( dm, path ), lineColumns, fstabEntries, homePath } );
+            osproberEntries.append( { prettyName,
+                                      path,
+                                      file,
+                                      QString(),
+                                      canBeResized( dm, path, o ),
+                                      lineColumns,
+                                      fstabEntries,
+                                      homePath } );
             osproberCleanLines.append( line );
         }
     }
 
     if ( osproberCleanLines.count() > 0 )
     {
-        cDebug() << "os-prober lines after cleanup:" << Logger::DebugList( osproberCleanLines );
+        cDebug() << o << "os-prober lines after cleanup:" << Logger::DebugList( osproberCleanLines );
     }
     else
     {
-        cDebug() << "os-prober gave no output.";
+        cDebug() << o << "os-prober gave no output.";
     }
 
     Calamares::JobQueue::instance()->globalStorage()->insert( "osproberLines", osproberCleanLines );
@@ -436,18 +446,47 @@ isEfiSystem()
     return QDir( "/sys/firmware/efi/efivars" ).exists();
 }
 
+bool
+isEfiFilesystemSuitable(const Partition* candidate)
+{
+    auto type = candidate->fileSystem().type();
+    auto size = candidate->capacity();  // bytes
+
+    using CalamaresUtils::Units::operator""_MiB;
+
+    switch( type )
+    {
+        case FileSystem::Type::Fat32:
+            if ( size >= 300_MiB )
+            {
+                return true;
+            }
+            cWarning() << "FAT32 filesystem is too small (" << size << "bytes)";
+            return false;
+#ifdef WITH_KPMCORE4API
+        case FileSystem::Type::Fat12:
+#endif
+        case FileSystem::Type::Fat16:
+            cWarning() << "FAT12 and FAT16 are probably not supported by EFI";
+            return false;
+        default:
+            cWarning() << "EFI boot partition must be FAT32";
+            return false;
+    }
+}
+
+
 bool
 isEfiBootable( const Partition* candidate )
 {
     const auto flags = PartitionInfo::flags( candidate );
 
-    // TODO: with KPMCore 4, this comment is wrong: the flags
-    //       are remapped, and the ESP flag is the same as Boot.
 #if defined( WITH_KPMCORE4API )
+    // In KPMCore4, the flags are remapped, and the ESP flag is the same as Boot.
     static_assert( KPM_PARTITION_FLAG_ESP == KPM_PARTITION_FLAG( Boot ), "KPMCore API enum changed" );
     return flags.testFlag( KPM_PARTITION_FLAG_ESP );
 #else
-    /* If bit 17 is set, old-style Esp flag, it's OK */
+    // In KPMCore3, bit 17 is the old-style Esp flag, and it's OK
     if ( flags.testFlag( KPM_PARTITION_FLAG_ESP ) )
     {
         return true;
@@ -470,22 +509,19 @@ isEfiBootable( const Partition* candidate )
 }
 
 QString
-findFS( QString fsName, FileSystem::Type* fsType )
+canonicalFilesystemName( const QString& fsName, FileSystem::Type* fsType )
 {
-    QStringList fsLanguage { QLatin1String( "C" ) };  // Required language list to turn off localization
+    cPointerSetter type( fsType );
     if ( fsName.isEmpty() )
     {
-        fsName = QStringLiteral( "ext4" );
+        type = FileSystem::Ext4;
+        return QStringLiteral( "ext4" );
     }
 
-    FileSystem::Type tmpType = FileSystem::typeForName( fsName, fsLanguage );
-    if ( tmpType != FileSystem::Unknown )
+    QStringList fsLanguage { QLatin1String( "C" ) };  // Required language list to turn off localization
+
+    if ( ( type = FileSystem::typeForName( fsName, fsLanguage ) ) != FileSystem::Unknown )
     {
-        cDebug() << "Found filesystem" << fsName;
-        if ( fsType )
-        {
-            *fsType = tmpType;
-        }
         return fsName;
     }
 
@@ -496,7 +532,6 @@ findFS( QString fsName, FileSystem::Type* fsType )
         if ( 0 == QString::compare( fsName, FileSystem::nameForType( t, fsLanguage ), Qt::CaseInsensitive ) )
         {
             QString fsRealName = FileSystem::nameForType( t, fsLanguage );
-            cDebug() << "Filesystem name" << fsName << "translated to" << fsRealName;
             if ( fsType )
             {
                 *fsType = t;
@@ -505,8 +540,7 @@ findFS( QString fsName, FileSystem::Type* fsType )
         }
     }
 
-    cDebug() << "Filesystem" << fsName << "not found, using ext4";
-    fsName = QStringLiteral( "ext4" );
+    cWarning() << "Filesystem" << fsName << "not found, using ext4";
     // fsType can be used to check whether fsName was a valid filesystem.
     if ( fsType )
     {
@@ -526,7 +560,8 @@ findFS( QString fsName, FileSystem::Type* fsType )
         }
     }
 #endif
-    return fsName;
+    type = FileSystem::Unknown;
+    return QStringLiteral( "ext4" );
 }
 
 }  // namespace PartUtils
