@@ -16,13 +16,12 @@
 #include "core/PartitionCoreModule.h"
 #include "core/PartitionInfo.h"
 
-#include "utils/CalamaresUtilsSystem.h"
-#include "utils/NamedEnum.h"
-#include "utils/Units.h"
-
 #include "GlobalStorage.h"
 #include "JobQueue.h"
+#include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
+#include "utils/NamedEnum.h"
+#include "utils/Units.h"
 
 #include <kpmcore/core/device.h>
 #include <kpmcore/core/partition.h>
@@ -109,6 +108,12 @@ doAutopartition( PartitionCoreModule* core, Device* dev, Choices::AutoPartitionO
         partType = isEfi ? PartitionTable::gpt : PartitionTable::msdos;
     }
 
+    // Looking up the defaultFsType (which should name a filesystem type)
+    // will log an error and set the type to Unknown if there's something wrong.
+    FileSystem::Type type = FileSystem::Unknown;
+    PartUtils::canonicalFilesystemName( o.defaultFsType, &type );
+    core->initLayout( type == FileSystem::Unknown ? FileSystem::Ext4 : type );
+
     core->createPartitionTable( dev, partType );
 
     if ( isEfi )
@@ -132,6 +137,7 @@ doAutopartition( PartitionCoreModule* core, Device* dev, Choices::AutoPartitionO
                                                                   *dev,
                                                                   PartitionRole( PartitionRole::Primary ),
                                                                   FileSystem::Fat32,
+                                                                  QString(),
                                                                   firstFreeSector,
                                                                   lastSector,
                                                                   KPM_PARTITION_FLAG( None ) );
@@ -180,6 +186,7 @@ doAutopartition( PartitionCoreModule* core, Device* dev, Choices::AutoPartitionO
                                                             *dev,
                                                             PartitionRole( PartitionRole::Primary ),
                                                             FileSystem::LinuxSwap,
+                                                            QStringLiteral( "swap" ),
                                                             lastSectorForRoot + 1,
                                                             dev->totalLogical() - 1,
                                                             KPM_PARTITION_FLAG( None ) );
@@ -190,6 +197,7 @@ doAutopartition( PartitionCoreModule* core, Device* dev, Choices::AutoPartitionO
                                                                      *dev,
                                                                      PartitionRole( PartitionRole::Primary ),
                                                                      FileSystem::LinuxSwap,
+                                                                     QStringLiteral( "swap" ),
                                                                      lastSectorForRoot + 1,
                                                                      dev->totalLogical() - 1,
                                                                      o.luksPassphrase,
