@@ -11,15 +11,9 @@
 
 #include "ChoicePage.h"
 
-#include "BootInfoWidget.h"
-#include "DeviceInfoWidget.h"
-#include "PartitionBarsView.h"
-#include "PartitionLabelsView.h"
-#include "PartitionSplitterWidget.h"
-#include "ReplaceWidget.h"
-#include "ScanningDialog.h"
+#include "Config.h"
+
 #include "core/BootLoaderModel.h"
-#include "core/Config.h"
 #include "core/DeviceModel.h"
 #include "core/KPMHelpers.h"
 #include "core/OsproberEntry.h"
@@ -28,6 +22,13 @@
 #include "core/PartitionCoreModule.h"
 #include "core/PartitionInfo.h"
 #include "core/PartitionModel.h"
+#include "gui/BootInfoWidget.h"
+#include "gui/DeviceInfoWidget.h"
+#include "gui/PartitionBarsView.h"
+#include "gui/PartitionLabelsView.h"
+#include "gui/PartitionSplitterWidget.h"
+#include "gui/ReplaceWidget.h"
+#include "gui/ScanningDialog.h"
 
 #include "Branding.h"
 #include "GlobalStorage.h"
@@ -117,9 +118,7 @@ ChoicePage::ChoicePage( Config* config, QWidget* parent )
     CalamaresUtils::unmarginLayout( m_itemsLayout );
 
     // Drive selector + preview
-    CALAMARES_RETRANSLATE( retranslateUi( this ); m_drivesLabel->setText( tr( "Select storage de&vice:" ) );
-                           m_previewBeforeLabel->setText( tr( "Current:" ) );
-                           m_previewAfterLabel->setText( tr( "After:" ) ); );
+    CALAMARES_RETRANSLATE_SLOT( &ChoicePage::retranslate );
 
     m_previewBeforeFrame->setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Expanding );
     m_previewAfterFrame->setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Expanding );
@@ -133,6 +132,41 @@ ChoicePage::ChoicePage( Config* config, QWidget* parent )
 
 ChoicePage::~ChoicePage() {}
 
+void
+ChoicePage::retranslate()
+{
+    retranslateUi( this );
+    m_drivesLabel->setText( tr( "Select storage de&vice:" ) );
+    m_previewBeforeLabel->setText( tr( "Current:" ) );
+    m_previewAfterLabel->setText( tr( "After:" ) );
+
+    updateSwapChoicesTr();
+    updateChoiceButtonsTr();
+}
+
+
+/** @brief Sets the @p model for the given @p box and adjusts UI sizes to match.
+ *
+ * The model provides data for drawing the items in the model; the
+ * drawing itself is done by the delegate, which may end up drawing a
+ * different width in the popup than in the collapsed combo box.
+ *
+ * Make the box wide enough to accomodate the whole expanded delegate;
+ * this avoids cases where the popup would truncate data being drawn
+ * because the overall box is sized too narrow.
+ */
+void
+setModelToComboBox( QComboBox* box, QAbstractItemModel* model )
+{
+    box->setModel( model );
+    if ( model->rowCount() > 0 )
+    {
+        QStyleOptionViewItem options;
+        options.initFrom( box );
+        auto delegateSize = box->itemDelegate()->sizeHint( options, model->index( 0, 0 ) );
+        box->setMinimumWidth( delegateSize.width() );
+    }
+}
 
 void
 ChoicePage::init( PartitionCoreModule* core )
@@ -145,15 +179,12 @@ ChoicePage::init( PartitionCoreModule* core )
 
     // We need to do this because a PCM revert invalidates the deviceModel.
     connect( core, &PartitionCoreModule::reverted, this, [=] {
-        m_drivesCombo->setModel( core->deviceModel() );
+        setModelToComboBox( m_drivesCombo, core->deviceModel() );
         m_drivesCombo->setCurrentIndex( m_lastSelectedDeviceIndex );
     } );
-    m_drivesCombo->setModel( core->deviceModel() );
+    setModelToComboBox( m_drivesCombo, core->deviceModel() );
 
-    connect( m_drivesCombo,
-             static_cast< void ( QComboBox::* )( int ) >( &QComboBox::currentIndexChanged ),
-             this,
-             &ChoicePage::applyDeviceChoice );
+    connect( m_drivesCombo, qOverload< int >( &QComboBox::currentIndexChanged ), this, &ChoicePage::applyDeviceChoice );
 
     connect( m_encryptWidget, &EncryptWidget::stateChanged, this, &ChoicePage::onEncryptWidgetStateChanged );
     connect( m_reuseHomeCheckBox, &QCheckBox::stateChanged, this, &ChoicePage::onHomeCheckBoxStateChanged );
@@ -246,6 +277,16 @@ ChoicePage::setupChoices()
         m_eraseButton->addOptionsComboBox( m_eraseSwapChoiceComboBox );
     }
 
+    if ( m_config->eraseFsTypes().count() > 1 )
+    {
+        m_eraseFsTypesChoiceComboBox = new QComboBox;
+        m_eraseFsTypesChoiceComboBox->addItems( m_config->eraseFsTypes() );
+        connect(
+            m_eraseFsTypesChoiceComboBox, &QComboBox::currentTextChanged, m_config, &Config::setEraseFsTypeChoice );
+        connect( m_config, &Config::eraseModeFilesystemChanged, this, &ChoicePage::onActionChanged );
+        m_eraseButton->addOptionsComboBox( m_eraseFsTypesChoiceComboBox );
+    }
+
     m_itemsLayout->addWidget( m_alongsideButton );
     m_itemsLayout->addWidget( m_replaceButton );
     m_itemsLayout->addWidget( m_eraseButton );
@@ -270,7 +311,7 @@ ChoicePage::setupChoices()
             m_config->setInstallChoice( id );
             updateNextEnabled();
 
-            emit actionChosen();
+            Q_EMIT actionChosen();
         }
         else  // An action was unpicked, either on its own or because of another selection.
         {
@@ -280,7 +321,7 @@ ChoicePage::setupChoices()
                 m_config->setInstallChoice( InstallChoice::NoChoice );
                 updateNextEnabled();
 
-                emit actionChosen();
+                Q_EMIT actionChosen();
             }
         }
     } );
@@ -291,14 +332,15 @@ ChoicePage::setupChoices()
 
     connect( this, &ChoicePage::actionChosen, this, &ChoicePage::onActionChanged );
     if ( m_eraseSwapChoiceComboBox )
+    {
         connect( m_eraseSwapChoiceComboBox,
                  QOverload< int >::of( &QComboBox::currentIndexChanged ),
                  this,
                  &ChoicePage::onEraseSwapChoiceChanged );
+    }
 
-    CALAMARES_RETRANSLATE( m_somethingElseButton->setText( tr( "<strong>Manual partitioning</strong><br/>"
-                                                               "You can create or resize partitions yourself." ) );
-                           updateSwapChoicesTr( m_eraseSwapChoiceComboBox ); );
+    updateSwapChoicesTr();
+    updateChoiceButtonsTr();
 }
 
 
@@ -403,8 +445,8 @@ ChoicePage::continueApplyDeviceChoice()
         checkInstallChoiceRadioButton( m_config->installChoice() );
     }
 
-    emit actionChosen();
-    emit deviceChosen();
+    Q_EMIT actionChosen();
+    Q_EMIT deviceChosen();
 }
 
 
@@ -442,9 +484,8 @@ ChoicePage::applyActionChoice( InstallChoice choice )
     case InstallChoice::Erase:
     {
         auto gs = Calamares::JobQueue::instance()->globalStorage();
-
         PartitionActions::Choices::AutoPartitionOptions options { gs->value( "defaultPartitionTableType" ).toString(),
-                                                                  gs->value( "defaultFileSystemType" ).toString(),
+                                                                  m_config->eraseFsType(),
                                                                   m_encryptWidget->passphrase(),
                                                                   gs->value( "efiSystemPartition" ).toString(),
                                                                   CalamaresUtils::GiBtoBytes(
@@ -460,14 +501,14 @@ ChoicePage::applyActionChoice( InstallChoice choice )
                 } ),
                 [=] {
                     PartitionActions::doAutopartition( m_core, selectedDevice(), options );
-                    emit deviceChosen();
+                    Q_EMIT deviceChosen();
                 },
                 this );
         }
         else
         {
             PartitionActions::doAutopartition( m_core, selectedDevice(), options );
-            emit deviceChosen();
+            Q_EMIT deviceChosen();
         }
     }
     break;
@@ -482,8 +523,6 @@ ChoicePage::applyActionChoice( InstallChoice choice )
                 [] {},
                 this );
         }
-        updateNextEnabled();
-
         connect( m_beforePartitionBarsView->selectionModel(),
                  SIGNAL( currentRowChanged( QModelIndex, QModelIndex ) ),
                  this,
@@ -507,7 +546,6 @@ ChoicePage::applyActionChoice( InstallChoice choice )
                 },
                 this );
         }
-        updateNextEnabled();
 
         connect( m_beforePartitionBarsView->selectionModel(),
                  SIGNAL( currentRowChanged( QModelIndex, QModelIndex ) ),
@@ -519,6 +557,7 @@ ChoicePage::applyActionChoice( InstallChoice choice )
     case InstallChoice::Manual:
         break;
     }
+    updateNextEnabled();
     updateActionChoicePreview( choice );
 }
 
@@ -985,7 +1024,8 @@ ChoicePage::updateActionChoicePreview( InstallChoice choice )
 
         SelectionFilter filter = []( const QModelIndex& index ) {
             return PartUtils::canBeResized(
-                static_cast< Partition* >( index.data( PartitionModel::PartitionPtrRole ).value< void* >() ) );
+                static_cast< Partition* >( index.data( PartitionModel::PartitionPtrRole ).value< void* >() ),
+                Logger::Once() );
         };
         m_beforePartitionBarsView->setSelectionFilter( filter );
         m_beforePartitionLabelsView->setSelectionFilter( filter );
@@ -1074,7 +1114,8 @@ ChoicePage::updateActionChoicePreview( InstallChoice choice )
         {
             SelectionFilter filter = []( const QModelIndex& index ) {
                 return PartUtils::canBeReplaced(
-                    static_cast< Partition* >( index.data( PartitionModel::PartitionPtrRole ).value< void* >() ) );
+                    static_cast< Partition* >( index.data( PartitionModel::PartitionPtrRole ).value< void* >() ),
+                    Logger::Once() );
             };
             m_beforePartitionBarsView->setSelectionFilter( filter );
             m_beforePartitionLabelsView->setSelectionFilter( filter );
@@ -1111,7 +1152,7 @@ ChoicePage::updateActionChoicePreview( InstallChoice choice )
     }
 
     // Also handle selection behavior on beforeFrame.
-    QAbstractItemView::SelectionMode previewSelectionMode;
+    QAbstractItemView::SelectionMode previewSelectionMode = QAbstractItemView::NoSelection;
     switch ( m_config->installChoice() )
     {
     case InstallChoice::Replace:
@@ -1219,10 +1260,12 @@ operator<<( QDebug& s, PartitionIterator& it )
 void
 ChoicePage::setupActions()
 {
+    Logger::Once o;
+
     Device* currentDevice = selectedDevice();
     OsproberEntryList osproberEntriesForCurrentDevice = getOsproberEntriesForDevice( currentDevice );
 
-    cDebug() << "Setting up actions for" << currentDevice->deviceNode() << "with"
+    cDebug() << o << "Setting up actions for" << currentDevice->deviceNode() << "with"
              << osproberEntriesForCurrentDevice.count() << "entries.";
 
     if ( currentDevice->partitionTable() )
@@ -1268,12 +1311,12 @@ ChoicePage::setupActions()
 
     for ( auto it = PartitionIterator::begin( currentDevice ); it != PartitionIterator::end( currentDevice ); ++it )
     {
-        if ( PartUtils::canBeResized( *it ) )
+        if ( PartUtils::canBeResized( *it, o ) )
         {
             cDebug() << Logger::SubEntry << "contains resizable" << it;
             atLeastOneCanBeResized = true;
         }
-        if ( PartUtils::canBeReplaced( *it ) )
+        if ( PartUtils::canBeReplaced( *it, o ) )
         {
             cDebug() << Logger::SubEntry << "contains replaceable" << it;
             atLeastOneCanBeReplaced = true;
@@ -1402,7 +1445,7 @@ ChoicePage::setupActions()
     }
     else
     {
-        cDebug() << "Replace button suppressed because none can be replaced.";
+        cDebug() << "No partitions available for replace-action.";
         force_uncheck( m_grp, m_replaceButton );
     }
 
@@ -1412,7 +1455,7 @@ ChoicePage::setupActions()
     }
     else
     {
-        cDebug() << "Alongside button suppressed because none can be resized.";
+        cDebug() << "No partitions available for resize-action.";
         force_uncheck( m_grp, m_alongsideButton );
     }
 
@@ -1422,8 +1465,8 @@ ChoicePage::setupActions()
     }
     else
     {
-        cDebug() << "Erase button suppressed"
-                 << "mount?" << atLeastOneIsMounted << "raid?" << isInactiveRAID;
+        cDebug() << "No partitions ("
+                 << "any-mounted?" << atLeastOneIsMounted << "is-raid?" << isInactiveRAID << ") for erase-action.";
         force_uncheck( m_grp, m_eraseButton );
     }
 
@@ -1570,56 +1613,66 @@ ChoicePage::updateNextEnabled()
     if ( enabled != m_nextEnabled )
     {
         m_nextEnabled = enabled;
-        emit nextStatusChanged( enabled );
+        Q_EMIT nextStatusChanged( enabled );
     }
 }
 
 void
-ChoicePage::updateSwapChoicesTr( QComboBox* box )
+ChoicePage::updateSwapChoicesTr()
 {
-    if ( !box )
+    if ( !m_eraseSwapChoiceComboBox )
     {
         return;
     }
 
     static_assert( SwapChoice::NoSwap == 0, "Enum values out-of-sync" );
-    for ( int index = 0; index < box->count(); ++index )
+    for ( int index = 0; index < m_eraseSwapChoiceComboBox->count(); ++index )
     {
         bool ok = false;
         int value = 0;
 
-        switch ( value = box->itemData( index ).toInt( &ok ) )
+        switch ( value = m_eraseSwapChoiceComboBox->itemData( index ).toInt( &ok ) )
         {
         // case 0:
         case SwapChoice::NoSwap:
             // toInt() returns 0 on failure, so check for ok
             if ( ok )  // It was explicitly set to 0
             {
-                box->setItemText( index, tr( "No Swap" ) );
+                m_eraseSwapChoiceComboBox->setItemText( index, tr( "No Swap" ) );
             }
             else
             {
-                cWarning() << "Box item" << index << box->itemText( index ) << "has non-integer role.";
+                cWarning() << "Box item" << index << m_eraseSwapChoiceComboBox->itemText( index ) << "has non-integer role.";
             }
             break;
         case SwapChoice::ReuseSwap:
-            box->setItemText( index, tr( "Reuse Swap" ) );
+            m_eraseSwapChoiceComboBox->setItemText( index, tr( "Reuse Swap" ) );
             break;
         case SwapChoice::SmallSwap:
-            box->setItemText( index, tr( "Swap (no Hibernate)" ) );
+            m_eraseSwapChoiceComboBox->setItemText( index, tr( "Swap (no Hibernate)" ) );
             break;
         case SwapChoice::FullSwap:
-            box->setItemText( index, tr( "Swap (with Hibernate)" ) );
+            m_eraseSwapChoiceComboBox->setItemText( index, tr( "Swap (with Hibernate)" ) );
             break;
         case SwapChoice::SwapFile:
-            box->setItemText( index, tr( "Swap to file" ) );
+            m_eraseSwapChoiceComboBox->setItemText( index, tr( "Swap to file" ) );
             break;
         default:
-            cWarning() << "Box item" << index << box->itemText( index ) << "has role" << value;
+            cWarning() << "Box item" << index << m_eraseSwapChoiceComboBox->itemText( index ) << "has role" << value;
         }
     }
 }
 
+void
+ChoicePage::updateChoiceButtonsTr()
+{
+    if ( m_somethingElseButton )
+    {
+        m_somethingElseButton->setText( tr( "<strong>Manual partitioning</strong><br/>"
+                                            "You can create or resize partitions yourself." ) );
+    }
+}
+
 int
 ChoicePage::lastSelectedDeviceIndex()
 {
