@@ -15,7 +15,7 @@
 #include "ui_ChoicePage.h"
 
 
-#include "core/Config.h"
+#include "Config.h"
 #include "core/OsproberEntry.h"
 
 #include <QMutex>
@@ -101,6 +101,8 @@ private slots:
     /// @brief Calls onActionChanged() as needed.
     void onEraseSwapChoiceChanged();
 
+    void retranslate();
+
 private:
     bool calculateNextEnabled() const;
     void updateNextEnabled();
@@ -122,7 +124,8 @@ private:
     void setupEfiSystemPartitionSelector();
 
     // Translations support
-    void updateSwapChoicesTr( QComboBox* box );
+    void updateSwapChoicesTr();
+    void updateChoiceButtonsTr();
 
     Config* m_config;
     bool m_nextEnabled;
@@ -138,7 +141,9 @@ private:
     Calamares::PrettyRadioButton* m_eraseButton;
     Calamares::PrettyRadioButton* m_replaceButton;
     Calamares::PrettyRadioButton* m_somethingElseButton;
-    QComboBox* m_eraseSwapChoiceComboBox;  // UI, see also m_eraseSwapChoice
+    QComboBox* m_eraseSwapChoiceComboBox = nullptr;  // UI, see also Config's swap choice
+    QComboBox* m_eraseFsTypesChoiceComboBox = nullptr;  // UI, see also Config's erase-mode FS
+
 
     DeviceInfoWidget* m_deviceInfoWidget;
 
