@@ -44,6 +44,9 @@ private Q_SLOTS:
     void testHostActions();
     void testPasswordChecks();
     void testUserPassword();
+
+    void testAutoLogin_data();
+    void testAutoLogin();
 };
 
 UserTests::UserTests() {}
@@ -339,6 +342,43 @@ UserTests::testUserPassword()
     }
 }
 
+void
+UserTests::testAutoLogin_data()
+{
+    QTest::addColumn< QString >( "filename" );
+    QTest::addColumn< bool >( "autoLoginIsSet" );
+    QTest::addColumn< QString >( "autoLoginGroupName" );
+
+    QTest::newRow( "old, old" ) << "tests/6a-issue-1672.conf" << true << "derp";
+    QTest::newRow( "old, new" ) << "tests/6b-issue-1672.conf" << true << "derp";
+    QTest::newRow( "new, old" ) << "tests/6c-issue-1672.conf" << true << "derp";
+    QTest::newRow( "new, new" ) << "tests/6d-issue-1672.conf" << true << "derp";
+    QTest::newRow( "default" ) << "tests/6e-issue-1672.conf" << false << QString();
+}
+
+void
+UserTests::testAutoLogin()
+{
+    QFETCH( QString, filename );
+    QFETCH( bool, autoLoginIsSet );
+    QFETCH( QString, autoLoginGroupName );
+
+    // BUILD_AS_TEST is the source-directory path
+    QFile fi( QString( "%1/%2" ).arg( BUILD_AS_TEST, filename ) );
+    QVERIFY( fi.exists() );
+
+    bool ok = false;
+    const auto map = CalamaresUtils::loadYaml( fi, &ok );
+    QVERIFY( ok );
+    QVERIFY( map.count() > 0 );
+
+    Config c;
+    c.setConfigurationMap( map );
+
+    QCOMPARE( c.doAutoLogin(), autoLoginIsSet );
+    QCOMPARE( c.autoLoginGroup(), autoLoginGroupName );
+}
+
 
 QTEST_GUILESS_MAIN( UserTests )
 
