@@ -101,13 +101,16 @@ UsersPage::UsersPage( Config* config, QWidget* parent )
     connect( config, &Config::rootPasswordSecondaryChanged, ui->textBoxVerifiedRootPassword, &QLineEdit::setText );
     connect( config, &Config::rootPasswordStatusChanged, this, &UsersPage::reportRootPasswordStatus );
 
+    ui->textBoxFullName->setText( config->fullName() );
     connect( ui->textBoxFullName, &QLineEdit::textEdited, config, &Config::setFullName );
     connect( config, &Config::fullNameChanged, this, &UsersPage::onFullNameTextEdited );
 
+    ui->textBoxHostName->setText( config->hostName() );
     connect( ui->textBoxHostName, &QLineEdit::textEdited, config, &Config::setHostName );
     connect( config, &Config::hostNameChanged, ui->textBoxHostName, &QLineEdit::setText );
     connect( config, &Config::hostNameStatusChanged, this, &UsersPage::reportHostNameStatus );
 
+    ui->textBoxLoginName->setText( config->loginName() );
     connect( ui->textBoxLoginName, &QLineEdit::textEdited, config, &Config::setLoginName );
     connect( config, &Config::loginNameChanged, ui->textBoxLoginName, &QLineEdit::setText );
     connect( config, &Config::loginNameStatusChanged, this, &UsersPage::reportLoginNameStatus );
@@ -137,9 +140,17 @@ UsersPage::UsersPage( Config* config, QWidget* parent )
             config, &Config::requireStrongPasswordsChanged, ui->checkBoxRequireStrongPassword, &QCheckBox::setChecked );
     }
 
-    CALAMARES_RETRANSLATE_SLOT( &UsersPage::retranslate )
+    CALAMARES_RETRANSLATE_SLOT( &UsersPage::retranslate );
 
     onReuseUserPasswordChanged( m_config->reuseUserPasswordForRoot() );
+    onFullNameTextEdited( m_config->fullName() );
+    reportLoginNameStatus( m_config->loginNameStatus() );
+    reportHostNameStatus( m_config->hostNameStatus() );
+
+    ui->textBoxLoginName->setEnabled( m_config->isEditable( "loginName" ) );
+    ui->textBoxFullName->setEnabled( m_config->isEditable( "fullName" ) );
+
+    retranslate();
 }
 
 UsersPage::~UsersPage()
